# Operator - Sign PYTH-SPL Transaction

## Requirements

* 2 Operators

* Ensure both primary operators have their [Shard-Bearer Keys](../../pgp-key-provisioning.md)

* Both operators should print photographic evidence from digital cameras which is stored in a PGP signed repository. The photographs should be of the top and underside of the vacuum sealed object.

    * The operators should verify the commit signatures of the photographs they are printing against a list of permitted PGP keys (found in ceremonies repo)

* Shardfile on SD card

* Keychain SD card

* Air-gapped bundle

* Tamper proofing equipment

* Ceremony notes

    * AirgapOS hash

    * Trusted PGP key fingeprints IDs

## Procedure

1. Verify all transactions for the ceremony in the `ceremonies` repository, ensuring that all the transactions are properly signed by the proposer and the approver using PGP keys which have been checked into ceremonies repository.

1. Copy the transactions and signatures to an SD card

1. Enter the designated location with the 2 operators and all required equipment

1. Lock access to the location - there should be no inflow or outflow of people during the ceremony

1. Retrieve sealed Air-Gapped bundle and polaroid from locked storage

### Unsealing Tamper Proofing

{{ #include ../../../../../../component-documents/tamper-evidence-methods.md:vsbwf-procedure-unsealing}}

### Ceremony

1. Plug in SD card labelled "AirgapOS" into the air-gapped machine

1. Boot the computer and verify the hash of the version of AirgapOS that's booted 

1. Plug in SD card labelled "Keychain"

    * Load well known PGP keys of proposer and approver along with detached signatures of the keys 

        * `gpg --import <keyfile_name>`

1. Plug in the SD card with transactions and signatures

1. For each transaction, verify that the signature is made by trusted keys that are loaded in the gpg keyring:

    * `gpg --verify <detached_signature>`

1. Insert SD card labelled "Shardfile"

1. `keyfork recover shard --daemon`

    * Follow on screen prompts

1. As a last step, run the `icepick` command which is awaiting the transaction payload

    * `icepick workflow sol-transfer` 

    * Follow on screen prompts

1. Run `icepick workflow sol-broadcast` command

    * Wait for prompt and plug in fresh SD card

    * Await completion message before removing SD card

    * This command will set the computer into "awaiting mode", which will broadcast the signed transaction from the SD card once it's plugged back in

1. Unplug the SD card and pass it to the air-gapped machine operators

### Sign Transaction

1. Plug in SD card with transaction payload

1. Wait for the screen to display the transaction information. (NOT IMPLEMENTED)

    * In the background:

        * The transaction is constructed

        * Signatures of tx data are verified against well known keys which were loaded by operators into local GPG keychain and signed by operators (NOT IMPLEMENTED)

1. If any issues are detected with data you will be prompted and should initiate [incident response (todo)](todo)

1. Wait for the "completed" message

1. Unplug and give the SD card back to the online machine operator

### Broadcast Transaction

1. Online machine operator takes the SD card to online machine and plugs it in

1. The still running process from running the command to create the transaction in [Obtain Transaction Request](#obtain-transaction-request) will broadcast the transaction automatically

1. Await the "completed" message

### Finalization

1. Shut down online machine

1. Shut down the air gapped machine

#### Sealing

1. Gather all the original items that were in the air-gapped bundle:

    * Air-gapped computer

    * AirgapOS SD card

    * Shardfile SD card

    * Keychain SD card

{{ #include ../../../../../../component-documents/tamper-evidence-methods.md:vsbwf-procedure-sealing}}

